{% extends "base.html" %}
{% load static %}

{% block heading %}<h4>
    <img src="{% static "svg/home.svg" %}" width="30" height="30" alt="Home">
    Welcome</h4>{%endblock%}

{% block content %}
<div class="alert alert-warning" role="alert">
    CameraHub is still in beta, so there may be some rough edges. Please <a
        href="https://github.com/djjudas21/camerahub/issues">report bugs</a> if you find them!
</div>

<div class="jumbotron">
    <div class="row">
        <div class="col-sm-9">
            <h1 class="display-4">Welcome to CameraHub</h1>
            <p class="lead">an app for cataloguing vintage cameras, lenses, films, negatives & prints</p>
        </div>
        <div class="col-sm-3">
            <img src="{% static "svg/camera.svg" %}" class="float-right img-fluid" style="max-width:128px"
                alt="CameraHub">
        </div>
    </div>
    <hr class="my-4">
    {% if user.is_authenticated %}
    <p>Browse and track your collection using the menus above.</p>
    {% else %}
    <p>Public data about camera models, lens models and much more is available to browse without logging in.
        Get started by using the public data menu above.</p>
    <p><a href="{% url 'login' %}">Login</a> or <a href="{% url 'django_registration_register' %}">register</a> to start
        tracking private data about your own collection!</p>
    {% endif %}
</div>
{% endblock %}
