{% extends "detail.html" %}
{% load boolicontag %}

{% block content %}
<table class="table table-hover">
  {% if object.negative is not None %}
  <tr>
    <td>Negative</td>
    <td><a href="{% url 'negative-detail' object.negative.id_owner %}">{{ object.negative }}</a></td>
  </tr>
  {% endif %}
  {% if object.print is not None %}
  <tr>
    <td>Print</td>
    <td>{{ object.print }}</td>
  </tr>
  {% endif %}
  {% if object.filename is not None %}
  <tr>
    <td>Filename</td>
    <td>{{ object.filename }}</td>
  </tr>
  {% endif %}
  {% if object.date is not None %}
  <tr>
    <td>Date</td>
    <td>{{ object.date }}</td>
  </tr>
  {% endif %}
  {% if object.colour is not None %}
  <tr>
    <td>Colour</td>
    <td>{{ object.colour|boolicontag }}</td>
  </tr>
  {% endif %}
  {% if object.width is not None and object.height is not None %}
  <tr>
    <td>Size</td>
    <td>{{ object.width }} &times; {{ object.height }}</td>
  </tr>
  {% endif %}
</table>
{% endblock %}
