{% extends "detail.html" %}

{% block content %}
<table class="table table-hover">
  <tr>
    <td>Type</td>
    <td>{{ object.type }}</td>
  </tr>
  <tr>
    <td>Shortname</td>
    <td>{{ object.shortname }}</td>
  </tr>
  {% if object.attenuation is not None %}
  <tr>
    <td>Attenuation</td>
    <td>{{ object.attenuation }}</td>
  </tr>
  {% endif %}
</table>
{% endblock %}
