{% extends "detail.html" %}
{% load boolicontag %}

{% block content %}
<table class="table table-hover">
  <tr>
    <td>Process name</td>
    <td>{{ object.name }}</td>
  </tr>
  {% if object.colour is not None %}
  <tr>
    <td>Colour</td>
    <td>{{ object.colour|boolicontag }}</td>
  </tr>
  {% endif %}
  {% if object.positive is not None %}
  <tr>
    <td>Positive</td>
    <td>{{ object.positive|boolicontag }}</td>
  </tr>
  {% endif %}
  <tr>
    <th colspan="2">Misc</th>
  </tr>
  {% if object.created_at is not None %}
  <tr>
    <td>Created</td>
    <td>{{ object.created_at }}{% if object.created_by is not None %} by {{ object.created_by }}{% endif %}</td>
  </tr>
  {% endif %}
  {% if object.updated_at is not None %}
  <tr>
    <td>Last updated</td>
    <td>{{ object.updated_at }}{% if object.updated_by is not None %} by {{ object.updated_by }}{% endif %}</td>
  </tr>
  {% endif %}
</table>
{% endblock %}
