{% extends "detail.html" %}
{% load boolicontag %}

{% block content %}
<table class="table table-hover">
    <tr>
        <th>Camera model</th>
        <td>{% if object.cameramodel is not None %}<a
                href="{% url 'cameramodel-detail' object.cameramodel.slug %}">{{ object.cameramodel }}</a>{% endif %}
        </td>
    </tr>
    {% if object.acquired is not None %}
    <tr>
        <td>Acquired</td>
        <td>{{ object.acquired }}</td>
    </tr>
    {% endif %}
    {% if object.cost is not None %}
    <tr>
        <td>Cost</td>
        <td>{{ object.cost }}</td>
    </tr>
    {% endif %}
    {% if object.serial is not None %}
    <tr>
        <td>Serial</td>
        <td><code>{{ object.serial }}</code></td>
    </tr>
    {% endif %}
    {% if object.datecode is not None %}
    <tr>
        <td>Datecode</td>
        <td><code>{{ object.datecode }}</code></td>
    </tr>
    {% endif %}
    {% if object.manufactured is not None %}
    <tr>
        <td>Manufactured</td>
        <td>{{ object.manufactured }}</td>
    </tr>
    {% endif %}
    {% if object.own is not None %}
    <tr>
        <td>Own</td>
        <td>{{ object.own|boolicontag }}</td>
    </tr>
    {% endif %}
    {% if object.lens is not None %}
    <tr>
        <td>Lens</td>
        <td>{{ object.lens }}</td>
    </tr>
    {% endif %}
    {% if object.notes is not None %}
    <tr>
        <td>Notes</td>
        <td>{{ object.notes }}</td>
    </tr>
    {% endif %}
    {% if object.lost is not None %}
    <tr>
        <td>Lost</td>
        <td>{{ object.lost }}</td>
    </tr>
    {% endif %}
    {% if object.lost_price is not None %}
    <tr>
        <td>Lost price</td>
        <td>{{ object.lost_price }}</td>
    </tr>
    {% endif %}
    {% if object.source is not None %}
    <tr>
        <td>Source</td>
        <td>{{ object.source }}</td>
    </tr>
    {% endif %}
    {% if object.condition is not None %}
    <tr>
        <td>Condition</td>
        <td>{{ object.condition }}</td>
    </tr>
    {% endif %}
    {% if object.condition_notes is not None %}
    <tr>
        <td>Condition notes</td>
        <td>{{ object.condition_notes }}</td>
    </tr>
    {% endif %}
</table>
{% endblock %}

{% block moreactions %}
<li>Load film, or something</li>
{%endblock%}
